@@ -1,19 +1,23 @@
 import sqlite3
 from os.path import join
+import requests
 
-from tenyksclient.client import Client, run_client
-from tenyksclient.config import settings
+from tenyksservice import TenyksService, run_service, FilterChain
+from tenyksservice.config import settings
 
 
-class TenyksLeetPoints(Client):
+class TenyksLeetPoints(TenyksService):
     irc_message_filters = {
-        'add_points': [r'^give (?P<points>[0-9]*) points to (?P<nick>[a-zA-Z0-9-_`]*)$',
-                       r'^\+(?P<points>[0-9]*) to (?P<nick>[a-zA-Z0-9-_`]*)$'],
-        'remove_points': [r'^remove (?P<points>[0-9]*) points from (?P<nick>[a-zA-Z0-9-_`]*)$',
-                          r'^\-(?P<points>[0-9]*) to (?P<nick>[a-zA-Z0-9-_`]*)$'],
-        'highscore': [r'highscore', r'scores', r'highscores', 'what are everyone\'s points?'],
+        'add_points': FilterChain(
+            [r'^(give|\+)\s*(?P<points>[0-9]*)\s*(point[s]*)* to (?P<nick>[a-zA-Z0-9-_`]*)\s*$'],
+            direct_only=True),
+        'remove_points': FilterChain(
+            [r'^(take|\-)\s*(?P<points>[0-9]*)\s*(point[s]*)* from (?P<nick>[a-zA-Z0-9-_`]*)\s*$'],
+            direct_only=True),
+        'highscore': FilterChain(
+            [r'high scores', r'highscore', r'scores', r'highscores',
+             'what are everyone\'s points?'], direct_only=True)
     }
-    direct_only = True
 
     def __init__(self, *args, **kwargs):
         super(TenyksLeetPoints, self).__init__(*args, **kwargs)
@@ -57,9 +61,10 @@ class TenyksLeetPoints(Client):
         self.send('{nick}: Done.'.format(nick=data['nick']), data)
 
     def handle_highscore(self, data, match):
-        self.send("Highscores: ", data)
-        for person in self.fetch_conspirators(self.fetch_cursor()):
-            self.send("{0}: {1}".format(person[1], person[2]), data)
+        resp = requests.post('http://ix.io?f:0={}'.format(
+            ''.join(['{} {}\n'.format(i[1], i[2])
+                  for i in self.fetch_conspirators(self.fetch_cursor())])))
+        self.send('Highscores: ', resp.content)
 
     def increment_points(self, cur, nick, points):
         result = cur.execute("""
@@ -107,7 +112,7 @@ class TenyksLeetPoints(Client):
         cur.executescript(table_sql)
 
 def main():
-    run_client(TenyksLeetPoints)
+    run_service(TenyksLeetPoints)
 
 if __name__ == '__main__':
     main()
