@@ -1,6 +1,6 @@
 import mpd
 
-from tenyksclient.client import Client, run_client
+from tenyks.client import Client, run_client
 
 
 class TenyksMpdMusic(Client):
