@@ -1,6 +1,6 @@
 import random
 
-from tenyksclient.client import Client, run_client
+from tenyks.client import Client, run_client
 
 
 class TenyksOutOfContext(Client):
